@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-12-30'; # DATE
-our $VERSION = '1.43'; # VERSION
+our $DATE = '2016-01-07'; # DATE
+our $VERSION = '1.44'; # VERSION
 
 use 5.010001;
 use strict;
@@ -595,10 +595,10 @@ sub _read_config {
 
     $log->tracef("[pericmd] Finding config files ...");
     my $res = Perinci::CmdLine::Util::Config::read_config(
-        config_paths    => $r->{config_paths},
-        config_filename => $self->config_filename,
-        config_dirs     => $self->config_dirs,
-        program_name    => $self->program_name,
+        config_paths     => $r->{config_paths},
+        config_filename  => $self->config_filename,
+        config_dirs      => $self->config_dirs,
+        program_name     => $self->program_name,
     );
     die $res unless $res->[0] == 200;
     $r->{config} = $res->[2];
@@ -1410,7 +1410,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.43 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-12-30.
+This document describes version 1.44 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-01-07.
 
 =head1 DESCRIPTION
 
@@ -1980,9 +1980,9 @@ user's home and then system location. On Unix, it's C<< [ "$ENV{HOME}/.config",
 $ENV{HOME}, "/etc"] >>. If $ENV{HOME} is empty, getpwuid() is used to get home
 directory entry.
 
-=head2 config_filename => str
+=head2 config_filename => str|array[str]
 
-Configuration filename. The default is C<< program_name . ".conf" >>. For
+Configuration filename(s). The default is C<< program_name . ".conf" >>. For
 example, if your program is named C<foo-bar>, config_filename will be
 C<foo-bar.conf>.
 
@@ -2235,7 +2235,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
