@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util::Config;
 
-our $DATE = '2015-12-30'; # DATE
-our $VERSION = '1.43'; # VERSION
+our $DATE = '2016-01-07'; # DATE
+our $VERSION = '1.44'; # VERSION
 
 use 5.010;
 use strict;
@@ -31,10 +31,10 @@ sub get_default_config_dirs {
 $SPEC{read_config} = {
     v => 1.1,
     args => {
-        config_paths => {},
-        config_filenames => {},
-        config_dirs => {},
-        program_name => {},
+        config_paths    => {},
+        config_filename => {},
+        config_dirs     => {},
+        program_name    => {},
     },
 };
 sub read_config {
@@ -48,11 +48,13 @@ sub read_config {
     if ($args{config_paths}) {
         $paths = $args{config_paths};
     } else {
-        my $name = $args{config_filename} //
+        my $names = $args{config_filename} //
             $args{program_name} . ".conf";
         for my $dir (@$config_dirs) {
-            my $path = "$dir/" . $name;
-            push @$paths, $path if -e $path;
+            for my $name (ref($names) eq 'ARRAY' ? @$names : ($names)) {
+                my $path = "$dir/" . $name;
+                push @$paths, $path if -e $path;
+            }
         }
     }
 
@@ -191,7 +193,7 @@ Perinci::CmdLine::Util::Config - Utility routines related to config files
 
 =head1 VERSION
 
-This document describes version 1.43 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-12-30.
+This document describes version 1.44 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2016-01-07.
 
 =head1 FUNCTIONS
 
@@ -262,7 +264,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<config_dirs> => I<any>
 
-=item * B<config_filenames> => I<any>
+=item * B<config_filename> => I<any>
 
 =item * B<config_paths> => I<any>
 
@@ -303,7 +305,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
